/* *********************************************************** getargs.h *** *
 * ϴؿ إåե
 *
 * Copyright (C) 1998-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
 * Okayama University
 *                                    Time-stamp: <03/03/04 21:32:47 sugaya>
 * ************************************************************************* */
#ifndef	__GETARGS_H__
#define	__GETARGS_H__

void	usage 		(void);
void	version 	(void);
int	getargs 	(int		argc,
			 char		**argv,
			 TEOption	**opt,
			 TEConfig	**tc);

#endif	/* __GETARGS_H__ */

/* **************************************************** End of getargs.h *** */
